Standard prior file
-------------------

4s.prior -> 128s.prior : built to match the ROQ basis sets from <https://git.ligo.org/lscsoft/ROQ_data/tree/master/IMRPhenomPv2>

A figure of the component mass ranges spanned by the priors.

![](../../docs/mass_ranges_for_priors.png)
